@@ -41,7 +41,7 @@ use strict;
 
     require_version DBI 1.61;
 
-    $VERSION = '9.0.0.0001';
+    $VERSION = '9.1.0.0001';
 
     bootstrap DBD::cubrid $VERSION;
 
@@ -317,6 +317,9 @@ use strict;
         for my $row (@$desc) {
 
             my $type = $row->{type};
+            if (!defined($type)) {
+                $type = "NULL";
+            }
 
             my $info = {
                 TABLE_CAT               => $catalog,
@@ -451,6 +454,9 @@ use strict;
                     $info->{COLUMN_SIZE} = 1073741823;
                 }
             }
+            elsif ($type =~ /^NULL$/) {
+                $info->{DATA_TYPE} = SQL_UNKNOWN_TYPE;
+            }
             else {
                 $info->{DATA_TYPE} = SQL_VARCHAR;
             }
@@ -643,6 +649,8 @@ use strict;
     1, 0, 2, 0, 0, 0, "BIGINT", -1, -1, SQL_INTEGER, -1, 10, -1],
 ["DATETIME", SQL_TYPE_TIMESTAMP, 23, q{DATETIME '}, q{'}, undef,
     1, 0, 2, 0, 0, 0, "DATETIME", -1, -1, SQL_DATETIME, 3, -1, -1],
+["ENUM", SQL_VARCHAR, 0, undef, undef, undef,
+    1, 0, 3, 0, 0, 0, "ENUM", -1, -1, SQL_VARCHAR, -1, -1, -1],
 ["BLOB", SQL_BLOB, 0, undef, undef, undef,
     1, 0, 3, 0, 0, 0, "BLOB", -1, -1, SQL_BLOB, -1, -1, -1],
 ["CLOB", SQL_CLOB, 0, undef, undef, undef,
@@ -1140,6 +1148,7 @@ CLOB. The following are data types supported by CUBRID.
     | TIMESTAMP     | SQL_TYPE_TIMESTAMP    |
     | BIGINT        | SQL_BIGINT            |
     | DATETIME      | SQL_TYPE_TIMESTAMP    |
+    | ENUM          | SQL_VARCHAR           |
     -----------------------------------------
     | BLOB          | SQL_BLOB              |
     | CLOB          | SQL_CLOB              |
